// Copyright 2009 Xerox Corporation.  All rights reserved.
// Apache 2.0 License
// See file copying.txt

package com.xerox.adoc.locatingrules;

import java.util.regex.Pattern;
import java.io.FilenameFilter;

import java.io.File;

class Glob {

  Glob() {
  }


  // TODO: assumes fromPattern and toPattern apply only to local file component, not directory.
  static File replaceFilePattern(File file, String fromPattern, String toPattern) {
    String filename = file.getName();
    File dir = file.getParentFile();
    fromPattern = fixFromPattern(fromPattern);
    toPattern = fixToPattern(toPattern);
    return new File(dir, filename.replaceAll(fromPattern, toPattern));
  }

  static private String fixFromPattern(String fromPattern) {
    return "^(.*)" + fromPattern.replace("*", "(.*)") + "$";
  }

  // Quote special regex replacement characters '$' and '\'
  // and replace successive '*' with '$1', '$2', '$3', ...
  private static String fixToPattern(String toPattern) {
    StringBuilder result = new StringBuilder();
    result.append("$1");
    int i = 2;
    for (char c : toPattern.toCharArray()) {
      switch(c) {
      case '*':
        result.append("$");
        result.append(i);
        break;
      case '$':
        result.append("\\$");
        break;
      case '\\':
        result.append("\\\\");
        break;
      default:
        result.append(c);
      }
    }
    return result.toString();
  }

  // TODO: Fails to notice \\* in pattern is a literal
  static class FileNamePatternFilter implements FilenameFilter {
    private final Pattern pattern;

    FileNamePatternFilter(String pattern) {
      this.pattern = Pattern.compile(pattern.replace("*", ".*"));
    }

    public boolean accept(File dir, String name) {
      return pattern.matcher(name).matches();
    }
  }
}
