// Copyright 2009 Xerox Corporation.  All rights reserved.
// Apache 2.0 License
// See file copying.txt

package com.xerox.adoc.locatingrules;

import java.util.Collection;
import org.xml.sax.SAXException;

import java.util.Map;
import java.io.File;
import java.io.IOException;
import com.thaiopensource.xml.sax.XMLReaderCreator;
import com.thaiopensource.xml.sax.Sax2XMLReaderCreator;
import org.xml.sax.XMLReader;

class LocatingRules {
  private final File dir;
  private final File file;
  private final Map<File, File> srcTargetFiles; // src->target
  private static final XMLReaderCreator xmlReaderCreator = new Sax2XMLReaderCreator();

  LocatingRules(File file) throws SAXException {
    this.file = file;
    this.dir = file.getParentFile();
    this.srcTargetFiles = init();
  }

  private Map<File, File> init() throws SAXException {
    XMLReader reader = xmlReaderCreator.createXMLReader();
    LocatingRulesParser parser = new LocatingRulesParser(dir);
    parser.setParent(reader);
    try {
      if (LocatingRulesTask.DEBUG) System.out.println("parsing " + file.getCanonicalPath());
      parser.parse(file.getCanonicalPath());
      if (LocatingRulesTask.DEBUG) System.out.println("parsed "  + file.getCanonicalPath());
    } catch (IOException e) {
      throw new RuntimeException("Canot read file " + file, e);
    } catch (SAXException e) {
      throw new RuntimeException("Canot parse file " + file, e);
    }

    return parser.getTargetFiles();
  }

  File getLocatingRulesFile() {
    return file;
  }

  File getTargetFile(File src) {
    return srcTargetFiles.get(src);
  }

  Collection<File> getSourceFiles() {
    return srcTargetFiles.keySet();
  }

  Collection<File> getTargetFiles() {
    return srcTargetFiles.values();
  }
}
