// Copyright 2009 Xerox Corporation.  All rights reserved.
// Apache 2.0 License
// See file copying.txt

package com.xerox.adoc.locatingrules;

import java.util.ArrayList;
import java.util.Collection;
import com.thaiopensource.util.PropertyMapBuilder;
import com.thaiopensource.validate.SchemaReader;
import com.thaiopensource.xml.sax.ErrorHandlerImpl;
import org.xml.sax.SAXException;

import java.io.File;
import java.io.IOException;

class SourceDirectories {
  private final Collection<SourceDirectory> allSourceDirectories;
  private final ValidationDriverCache validationDriverCache;

  SourceDirectories(PropertyMapBuilder properties, SchemaReader schemaReader) {
    this.allSourceDirectories = new ArrayList<SourceDirectory>();
    this.validationDriverCache = new ValidationDriverCache(properties, schemaReader);
  }

  Collection<SourceDirectory> getSourceDirectories() {
    return allSourceDirectories;
  }
  
  boolean loadSchemas(File dir, File locatingRulesFile) throws SAXException, IOException {
    SourceDirectory sourceDirectory = new SourceDirectory(validationDriverCache, dir, locatingRulesFile);
    allSourceDirectories.add(sourceDirectory);
    return sourceDirectory.loadSchemas();
  }

  boolean validate(ErrorHandlerImpl eh, boolean verbose) {
    boolean hadError = false;
    for (SourceDirectory sourceDirectory : getSourceDirectories() ) {
      hadError |= sourceDirectory.validate(eh, verbose);
    }
    return hadError;
  }

}
