// Copyright 2009 Xerox Corporation.  All rights reserved.
// Apache 2.0 License
// See file copying.txt

package com.xerox.adoc.locatingrules;

import java.io.IOException;
import com.thaiopensource.xml.sax.ErrorHandlerImpl;
import java.util.Collection;
import org.xml.sax.SAXException;

import java.io.File;
import com.thaiopensource.validate.ValidationDriver;

class SourceDirectory {
  private final File dir;
  private final ValidationDriverCache validationDriverCache;
  private LocatingRules locatingRules;

  SourceDirectory(ValidationDriverCache validationDriverCache, File dir, File locatingRulesFile) throws SAXException {
    this.validationDriverCache = validationDriverCache;
    this.dir = dir;
    this.locatingRules = new LocatingRules(locatingRulesFile);
  }

  LocatingRules getLocatingRules() {
    return locatingRules;
  }

  File getDirectory() {
    return dir;
  }

  Collection<File> getSourceFiles() {
    return locatingRules.getSourceFiles();
  }

  Collection<File> getSchemaFiles() {
    return locatingRules.getTargetFiles();
  }

  File getSchemaFile(File src) {
    return locatingRules.getTargetFile(src);
  }

  boolean loadSchemas() throws SAXException, IOException {
    return validationDriverCache.loadSchemas(this);
  }

  boolean validate(ErrorHandlerImpl eh, boolean verbose) {
    boolean hadError = false;
    LocatingRules locatingRules = getLocatingRules();
    for (File src : getSourceFiles()) {
      if (src.exists()) {
        File rnc = getSchemaFile(src);
        ValidationDriver driver = validationDriverCache.getValidationDriver(rnc);
        if (verbose) System.out.println("Validating " + src + " with " + rnc);
        try {
          if (!driver.validate(ValidationDriver.fileInputSource(src)))
            hadError = true;
        } catch (SAXException e) {
          hadError = true;
          eh.printException(e);
        } catch (IOException e) {
          hadError = true;
          eh.printException(e);
        }
      } else {
        if (verbose) System.out.println("Not validating nonexistent src file "+ src);
      }
    }
    return hadError;
  }
}
