// Copyright 2009 Xerox Corporation.  All rights reserved.
// Apache 2.0 License
// See file copying.txt

package com.xerox.adoc.locatingrules;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashMap;
import com.thaiopensource.util.PropertyMapBuilder;
import com.thaiopensource.validate.SchemaReader;
import com.thaiopensource.validate.ValidationDriver;
import org.xml.sax.SAXException;

import java.util.Map;
import java.io.File;
import java.io.IOException;

class ValidationDriverCache {
  private final Map<File, ValidationDriver> schemaValidationDrivers;
  private final SchemaReader schemaReader;
  private final PropertyMapBuilder properties;

  ValidationDriverCache(PropertyMapBuilder properties, SchemaReader schemaReader) {
    this.properties = properties;
    this.schemaReader = schemaReader;
    this.schemaValidationDrivers = new HashMap<File, ValidationDriver>();
  }

  ValidationDriver getValidationDriver(File schemaFile) {
    return schemaValidationDrivers.get(schemaFile);
  }

  boolean loadSchemas(SourceDirectory sourceDirectory) throws SAXException, IOException {
    for (File schemaFile : sourceDirectory.getSchemaFiles()) {
      if (getValidationDriver(schemaFile) == null) {
        ValidationDriver driver = loadSchema(schemaFile);
        if (driver == null) return false;
        if (LocatingRulesTask.DEBUG) System.out.println("Loaded " + schemaFile);
        schemaValidationDrivers.put(schemaFile, driver);
      }
    }
    return true;
  }

  private ValidationDriver loadSchema(File schemaFile) throws SAXException, IOException {
    ValidationDriver driver = new ValidationDriver(properties.toPropertyMap(), schemaReader);
    if (driver.loadSchema(ValidationDriver.fileInputSource(schemaFile))) {
      return driver;
    } else {
      System.out.println("Failed to load "+ schemaFile);
      return null;
    }
  }
}
